@@ -137,14 +137,20 @@ def fragment_entity(e: Entity) -> Entity:
     spans = []
     fragments = []
     for m in matches:
+        while e.text[start].isspace():
+            start += 1
         frag_start = offset + start
         frag_end = offset + m.start()
         if frag_start != frag_end:
             spans.append((frag_start, frag_end))
             fragments.append(e.text[start : m.start()])
             start = m.end()
+
+    while e.text[start].isspace():
+        start += 1
     frag_start = offset + start
     frag_end = offset + len(e.text)
+
     if frag_start != frag_end:
         spans.append((frag_start, frag_end))
         fragments.append(e.text[start:])
